Learn R Programming

shoredate (version 1.1.1)

print.shoreline_date: Print shoreline dates to console

Description

Print the dates held in a shoreline_date object. Each date is printed with site name, elevation and highest density region. If the isobase direction is different or more are provided than the default, the directions and dates associated with these are printed separately.

Usage

# S3 method for shoreline_date
print(x, ...)

Value

Print the site names, elevations, non-default isobase directions and HDRs contained in a shoreline_date object to console.

Arguments

x

Object of class shoreline_date.

...

Additional arguments.

Examples

Run this code
target_point <- sf::st_sfc(sf::st_point(c(538310, 6544255)), crs = 32632)

# Reduce date resolution with cal_reso and elevation_reso for speed
target_date <- shoreline_date(site = target_point,
                              elevation = 70,
                              elev_reso = 1,
                              cal_reso = 400)

# Print to console
target_date

Run the code above in your browser using DataLab